%bcond_without otr

Summary:           IRC to other chat networks gateway
Name:              bitlbee
Version:           3.6
Release:    1%{?dist}
License:           GPLv2+ and MIT
URL:               https://www.bitlbee.org/
Source0:           https://get.bitlbee.org/src/%{name}-%{version}.tar.gz
Source1:           bitlbee.sysusersd
Patch0:            bitlbee-forkdaemon.patch
Patch1:            bitlbee-twitter.patch

BuildRequires:     gcc
BuildRequires:     make
BuildRequires:     glib2-devel >= 2.16
BuildRequires:     gnutls-devel
BuildRequires:     systemd-rpm-macros
%if %{with otr}
BuildRequires:     libotr-devel >= 4.0
%endif
BuildRequires:     libpurple-devel
%{?systemd_requires}
%{?sysusers_requires_compat}

BuildRequires:     %{_bindir}/python3
BuildRequires:     libxslt
BuildRequires:     docbook-style-xsl

%description
BitlBee is an IRC to other chat networks gateway. BitlBee can be used as
an IRC server which forwards everything you say to people on other chat
networks like XMPP/Jabber (including Google Talk and Hipchat) and Twitter
microblogging network (and all other Twitter API compatible services like
status.net). There are also plugins for facebook and steam, and even more
protocols can be used via libpurple.

%package devel
Summary:           Development files for bitlbee
Requires:          %{name} = %{version}-%{release}, pkgconfig

%description devel
The bitlbee-devel package includes header files necessary for building and
developing programs and plugins which use bitlbee.

%if %{with otr}
%package otr
Summary:           OTR plugin for bitlbee
Requires:          %{name} = %{version}-%{release}

%description otr
The bitlbee-otr package includes OTR plugin for bitlbee. Off-the-Record
messaging, commonly referred to as OTR, provides perfect forward secrecy
and malleable encryption.
%endif

%prep
echo With OTR %with_otr
%setup -q
%patch0 -p1 -b .forkdaemon
%patch1 -p1
touch -c -r bitlbee.conf{.forkdaemon,}

%build
export PYTHON="%{_bindir}/python3"
export CFLAGS="$RPM_OPT_FLAGS"
./configure \
  --prefix=%{_prefix} \
  --bindir=%{_sbindir} \
  --etcdir=%{_sysconfdir}/%{name} \
  --mandir=%{_mandir} \
  --datadir=%{_datadir}/%{name} \
  --config=%{_localstatedir}/lib/%{name} \
  --pcdir=%{_libdir}/pkgconfig \
  --plugindir=%{_libdir}/%{name} \
  --systemdsystemunitdir=%{_unitdir} \
  --strip=0 \
  --plugins=1 \
  --ssl=gnutls \
  --jabber=1 \
  --twitter=1 \
  --purple=1 \
%if %{with otr}
  --otr=plugin
%endif

%make_build VERBOSE=""
(cd doc/user-guide/ && make user-guide.html)

%install
%make_install install-etc install-dev install-systemd

install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_sysusersdir}/%{name}.conf

mkdir -p %{buildroot}{%{_localstatedir}/lib,%{_libdir}}/%{name}/

%pre
%sysusers_create_compat %{SOURCE1}

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%files
%license COPYING
%doc doc/{AUTHORS,CHANGES,CREDITS,FAQ,README}
%doc doc/user-guide/user-guide.html
%attr(0750,root,bitlbee) %dir %{_sysconfdir}/%{name}/
%attr(0640,root,bitlbee) %config(noreplace) %{_sysconfdir}/%{name}/*
%{_sbindir}/%{name}
%dir %{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man?/%{name}*
%attr(0750,bitlbee,bitlbee) %dir %{_localstatedir}/lib/%{name}/
%{_unitdir}/%{name}*
%{_sysusersdir}/%{name}.conf

%files devel
%doc doc/example_plugin.c
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%if %{with otr}
%files otr
%{_libdir}/%{name}/otr.so
%endif

%changelog
* Fri Jun 28 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6-1
- initial build
